# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_course_module import ResponseWrapperCourseModule

class TestResponseWrapperCourseModule(unittest.TestCase):
    """ResponseWrapperCourseModule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourseModule:
        """Test ResponseWrapperCourseModule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourseModule`
        """
        model = ResponseWrapperCourseModule()
        if include_optional:
            return ResponseWrapperCourseModule(
                done = True,
                result = public_api_server_connector_v2.models.course_module.CourseModule(
                    mandatory = True, 
                    is_published = True, 
                    is_active = True, 
                    title = '', 
                    public_description = '', 
                    short_description = '', 
                    image_id = '', 
                    available_at = 56, 
                    id = 56, 
                    course_id = 56, 
                    order = 56, 
                    submodules = [
                        public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                            order = 56, 
                            title = '', 
                            is_published = True, 
                            id = 56, 
                            module_id = 56, 
                            created_at = 56, )
                        ], 
                    lessons = [
                        public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                            submodule_id = 56, 
                            thread_id = 56, 
                            lesson_type = null, 
                            image_id = '', 
                            title = '', 
                            payload = '', 
                            is_active = True, 
                            is_published = True, 
                            mandatory = True, 
                            id = 56, 
                            module_id = 56, 
                            order = 56, 
                            public_key = '', 
                            content_blocks = [
                                public_api_server_connector_v2.models.content_block.ContentBlock(
                                    block_type = null, 
                                    order = 56, 
                                    is_expanded = True, 
                                    content = null, 
                                    id = 56, 
                                    lesson_id = 56, 
                                    created_at = 56, )
                                ], 
                            attached_files = [
                                public_api_server_connector_v2.models.attached_file.AttachedFile(
                                    order = 56, 
                                    file_id = 56, 
                                    id = 56, 
                                    lesson_id = 56, 
                                    created_at = 56, )
                                ], )
                        ], ),
                error = ''
            )
        else:
            return ResponseWrapperCourseModule(
                done = True,
        )
        """

    def testResponseWrapperCourseModule(self):
        """Test ResponseWrapperCourseModule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
