# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.token_info import TokenInfo

class TestTokenInfo(unittest.TestCase):
    """TokenInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenInfo:
        """Test TokenInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenInfo`
        """
        model = TokenInfo()
        if include_optional:
            return TokenInfo(
                api_key = public_api_server_connector_v2.models.api_key_get.ApiKeyGet(
                    name = '', 
                    id = 56, 
                    portal_id = 56, 
                    permissions = {
                        'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                            create = True, 
                            read = True, 
                            update = True, 
                            delete = True, )
                        }, 
                    openapi_specification_url = '', 
                    created_at = 56, 
                    last_used_at = 56, 
                    updated_at = 56, 
                    expires_at = 56, 
                    revoked_at = 56, ),
                portal = public_api_server_connector_v2.models.portal_info.PortalInfo(
                    id = 56, 
                    domain = '', ),
                owner = public_api_server_connector_v2.models.portal_member_base.PortalMemberBase(
                    id = 56, 
                    email = '', )
            )
        else:
            return TokenInfo(
                api_key = public_api_server_connector_v2.models.api_key_get.ApiKeyGet(
                    name = '', 
                    id = 56, 
                    portal_id = 56, 
                    permissions = {
                        'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                            create = True, 
                            read = True, 
                            update = True, 
                            delete = True, )
                        }, 
                    openapi_specification_url = '', 
                    created_at = 56, 
                    last_used_at = 56, 
                    updated_at = 56, 
                    expires_at = 56, 
                    revoked_at = 56, ),
                portal = public_api_server_connector_v2.models.portal_info.PortalInfo(
                    id = 56, 
                    domain = '', ),
                owner = public_api_server_connector_v2.models.portal_member_base.PortalMemberBase(
                    id = 56, 
                    email = '', ),
        )
        """

    def testTokenInfo(self):
        """Test TokenInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
