# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class HttpMethod(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    GET = 'GET'
    POST = 'POST'
    PUT = 'PUT'
    PATCH = 'PATCH'
    DELETE = 'DELETE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HttpMethod from a JSON string"""
        return cls(json.loads(json_str))


