# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.api_spec_api import ApiSpecApi


class TestApiSpecApi(unittest.IsolatedAsyncioTestCase):
    """ApiSpecApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ApiSpecApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_spec_count_spec_methods(self) -> None:
        """Test case for api_spec_count_spec_methods

        Count Spec Methods
        """
        pass

    async def test_api_spec_get_spec(self) -> None:
        """Test case for api_spec_get_spec

        Get Spec
        """
        pass

    async def test_api_spec_get_spec_methods(self) -> None:
        """Test case for api_spec_get_spec_methods

        Get Spec Methods
        """
        pass

    async def test_api_spec_get_spec_ui(self) -> None:
        """Test case for api_spec_get_spec_ui

        Get Spec Ui
        """
        pass


if __name__ == '__main__':
    unittest.main()
